@@ -1,6 +1,6 @@
-package Pcore::API::Majestic v0.6.0;
+package Pcore::API::Majestic v0.7.0;
 
-use Pcore -dist, -class, -const, -status, -export => { CONST => [qw[$MAJESTIC_INDEX_FRESH $MAJESTIC_INDEX_HISTORIC]] };
+use Pcore -dist, -class, -const, -result, -export => { CONST => [qw[$MAJESTIC_INDEX_FRESH $MAJESTIC_INDEX_HISTORIC]] };
 
 const our $MAJESTIC_INDEX_FRESH    => 1;
 const our $MAJESTIC_INDEX_HISTORIC => 2;
@@ -39,10 +39,10 @@ sub get_index_item_info ( $self, $domains, $datasource, $failover, $cb ) {
         $url_params,
         sub ($res) {
             if ( $res->is_success ) {
-                my $json = delete $res->{result};
+                my $json = delete $res->{data};
 
                 for my $item ( $json->{DataTables}->{Results}->{Data}->@* ) {
-                    $res->{result}->{ $domains->[ $item->{ItemNum} ] } = $item;
+                    $res->{data}->{ $domains->[ $item->{ItemNum} ] } = $item;
                 }
             }
 
@@ -78,19 +78,19 @@ sub _request ( $self, $url_params, $cb ) {
             my $api_res;
 
             if ( $res->status != 200 ) {
-                $api_res = status [ $res->status, $res->reason ];
+                $api_res = result [ $res->status, $res->reason ];
             }
             else {
                 my $json = eval { P->data->from_json( $res->body->$* ); };
 
                 if ($@) {
-                    $api_res = status [ 999, 'Invalid JSON body' ];
+                    $api_res = result [ 999, 'Invalid JSON body' ];
                 }
                 elsif ( $json->{Code} ne 'OK' ) {
-                    $api_res = status [ 999, $json->{ErrorMessage} ];
+                    $api_res = result [ 999, $json->{ErrorMessage} ];
                 }
                 else {
-                    $api_res = status 200, $json;
+                    $api_res = result 200, $json;
                 }
             }
 
